@@ -47,6 +47,15 @@ class DataSourceProcessingInfo(BaseModel):
     processed_documents_count: Optional[int] = Field(None, alias="documents_count_key")
 
 
+class ElasticsearchStatsResponse(BaseModel):
+    """Response model for Elasticsearch index statistics."""
+
+    model_config = ConfigDict(extra="ignore")
+
+    index_name: str = Field(..., description="Name of the index in Elasticsearch")
+    size_in_bytes: int = Field(..., ge=0, description="Size of the index in bytes")
+
+
 # Base request models
 class Confluence(BaseModel):
     """Model for Confluence-specific response fields"""
@@ -260,6 +269,40 @@ class UpdateFileDataSourceRequest(BaseUpdateDataSourceRequest):
         super().__init__(type=DataSourceType.FILE, **data)
 
 
+class CodeAnalysisDataSourceRequest(BaseModel):
+    """Model for provider-based datasource creation requests"""
+
+    model_config = ConfigDict(extra="ignore", populate_by_name=True)
+
+    name: str = Field(..., description="Datasource name")
+    description: Optional[str] = Field(None, description="Datasource description")
+    project_name: str = Field(..., description="Project name")
+    project_space_visible: bool = Field(False, alias="projectSpaceVisible")
+    branch: Optional[str] = Field(None, description="Git branch")
+    api_url: str = Field(..., description="Repository URL")
+    access_token: str = Field(..., description="Access token for repository")
+    analyzer: Optional[str] = Field(
+        None, description="Code analyzer type (e.g., Java, Python)"
+    )
+    datasource_root: str = Field("/", description="Root directory to analyze")
+
+
+class CodeExplorationDataSourceRequest(BaseModel):
+    """Model for CodeExplorationToolkit datasource creation requests"""
+
+    model_config = ConfigDict(extra="ignore", populate_by_name=True)
+
+    name: str = Field(..., description="Datasource name")
+    description: Optional[str] = Field(None, description="Datasource description")
+    project_name: str = Field(..., description="Project name")
+    project_space_visible: bool = Field(False, alias="projectSpaceVisible")
+    code_analysis_datasource_ids: List[str] = Field(
+        ...,
+        alias="code_analysis_datasource_ids",
+        description="List of CodeAnalysisToolkit datasource IDs",
+    )
+
+
 class DataSource(BaseModel):
     model_config = ConfigDict(
         extra="ignore",
